@@ -7,13 +7,14 @@ import click
 def remove(ctx, env_name):
     """Remove environments."""
     app = ctx.obj
+    app.ensure_environment_plugin_dependencies()
+
     if ctx.get_parameter_source('env_name').name == 'DEFAULT':
         env_name = app.env
 
-    if env_name in app.project.config.matrices:
-        environments = list(app.project.config.matrices[env_name]['envs'])
-    else:
-        environments = [env_name]
+    environments = (
+        list(app.project.config.matrices[env_name]['envs']) if env_name in app.project.config.matrices else [env_name]
+    )
 
     for env_name in environments:
         if env_name == app.env_active:
@@ -24,9 +25,9 @@ def remove(ctx, env_name):
 
         try:
             environment.check_compatibility()
-        except Exception:
+        except Exception:  # noqa: S112
             continue
 
-        if environment.exists():
+        if environment.exists() or environment.build_environment_exists():
             with app.status_waiting(f'Removing environment: {env_name}'):
                 environment.remove()
